@@ -108,7 +108,7 @@ compare_by_src (const void *a,
     return -1;
   else if (itema->src > itemb->src)
     return 1;
-  else 
+  else
     return 0;
 }
 
@@ -532,6 +532,31 @@ sysprof_capture_writer_cat (SysprofCaptureWriter *self,
           break;
         }
 
+        case SYSPROF_CAPTURE_FRAME_OVERLAY:
+          {
+            const SysprofCaptureOverlay *frame;
+            const char *src;
+            const char *dst;
+
+            if (!(frame = sysprof_capture_reader_read_overlay (reader)))
+              goto panic;
+
+            /* This should have been verified alrady when decoding */
+            assert (frame->frame.len >= (sizeof *frame + frame->src_len + 1 + frame->dst_len + 1));
+
+            src = &frame->data[0];
+            dst = &frame->data[frame->src_len+1];
+
+            sysprof_capture_writer_add_overlay (self,
+                                                frame->frame.time,
+                                                frame->frame.cpu,
+                                                frame->frame.pid,
+                                                frame->layer,
+                                                src,
+                                                dst);
+            break;
+          }
+
         default:
           /* Silently drop, which is better than looping. We could potentially
            * copy this over using the raw bytes at some point.
